@@ -32,7 +32,7 @@
 
 __copyright__ = 'Copyright (C) 2009, Purdue University'
 __license__ = 'BSD'
-__version__ = '0.11'
+__version__ = '0.12'
 
 
 import datetime
@@ -260,9 +260,28 @@ class CoreHelpers(object):
       ttl: string of ttl
     """
     target, zone_assignment = self.GetPTRTarget(target, view_name)
+    if( record_args_dict['assignment_host'].startswith('@.') ):
+      record_args_dict['assignment_host'] = record_args_dict[
+          'assignment_host'].lstrip('@.')
     self.core_instance.MakeRecord(u'ptr', target, zone_assignment,
                                   record_args_dict, view_name, ttl)
 
+  def RemovePTRRecord(self, record_type, target, zone_name, record_args_dict,
+                      view_name, ttl=None):
+    """Removes a ptr record.
+
+    Inputs:
+      target: string of target
+      record_args_dict: dictionary of record arguments
+      view_name: string of view name
+      ttl: string of ttl
+    """
+    if( record_args_dict['assignment_host'].startswith('@.') ):
+      record_args_dict['assignment_host'] = record_args_dict[
+          'assignment_host'].lstrip('@.')
+    self.core_instance.RemoveRecord(u'ptr', target, zone_name,
+                                    record_args_dict, view_name, ttl)
+
   def ListRecordsByCIDRBlock(self, cidr_block, view_name=None):
     """Lists records in user given cidr block.
 
@@ -282,8 +301,6 @@ class CoreHelpers(object):
     if( user_cidr.version() == 6 ):
       record_type = u'aaaa'
     zones = self.core_instance.ListZones()
-    if( not view_name ):
-      view_name = u'any'
 
     ptr_record_list = []
     fwd_record_list = []
@@ -299,6 +316,12 @@ class CoreHelpers(object):
 
     fwd_dict = self.db_instance.GetEmptyRowDict('records')
     fwd_dict['record_type'] = record_type
+    if( not view_name ):
+      view_name = u'any'
+    elif( view_name.endswith('_dep') or view_name == u'any' ):
+      fwd_dict['record_view_dependency'] = view_name
+    else:
+      fwd_dict['record_view_dependency'] = '%s_dep' % view_name
     fwd_args_dict = self.db_instance.GetEmptyRowDict(
         'record_arguments_records_assignments')
     fwd_args_dict['record_arguments_records_assignments_argument_name'] = (
@@ -576,6 +599,11 @@ class CoreHelpers(object):
           if( not record['view_name'].endswith('_dep') and record[
                 'view_name'] != u'any'):
             view_name = '%s_dep' % record['view_name']
+          if( record['record_type'] == u'ptr' ):
+            if( record['record_arguments'][
+                'assignment_host'].startswith('@.') ):
+              record['record_arguments']['assignment_host'] = record[
+                  'record_arguments']['assignment_host'].lstrip('@.')
           changed_view_dep.append((view_name, record['record_zone_name']))
           ttl = None
           if( 'ttl' in record ):
@@ -638,6 +666,4 @@ class CoreHelpers(object):
                                            record['view_name']), success)
     return row_count
 
-  def CIDRtoOrigin(self, cidr_block):
-    ip = IPy.IP(cidr_block)
-
+# vi: set ai aw sw=2:
